clear all
close all
clc
Data = xlsread('Dry_WithoutSpacer.xlsx');
X = Data(1:32,1);
Y = Data(1:32,10);

%fun = @(c, xdata) c(1) * ( 1 - c(2) * log( 1 + xdata / c(3) ) );
%c0  = [ 0.055, 0.5, 1.0];

fun = @(c, xdata) c(1) ./ (1 + exp (c(2) - c(3) * xdata));
c0  = [ 4.1041, 1.5890, 0.1970];

[cHat,r,J,cov,mse] = nlinfit( X, Y,fun,c0);
ci = nlparci(cHat,r,'Jacobian',J);

%plot(X,Y,'ko', X, fun(cHat, X), 'k-');
%hold on;
%plot(X, fun(ci(:,1),X) , 'r-', 'linewidth',2)
%plot(X, fun(ci(:,2),X) , 'b-', 'linewidth',2)
%,'MarkerFaceColor','k','MarkerSize',7);

Y_Fitted =fun(cHat,X); % fitted data of P/P0 vs. time to Logistic growth model
F = fit(X,Y_Fitted,'smoothingspline');

UpperCi = fun(ci(:,1),X); %Upper values of confidence intervals
U = fit(X,UpperCi,'smoothingspline');

LowerCi = fun(ci(:,2),X); %Lower values of confidence intervals
L = fit(X,LowerCi,'smoothingspline');

DifferenceWithFitted_Upper = U(X) - F(X); % Differenece between fitted data and upper CI limit
%D_U = fit(X,DifferenceWithFitted_Upper, 'smoothingspline');

DifferenceWithFitted_Lower = -(L(X) - F(X)); % Differenece between fitted data and lower CI limit
%D_L = fit(X,DifferenceWithFitted_Lower, 'smoothingspline');

plot(X,Y,'ko');
hold on;
plot(F, 'r-');
hold on;
shadedErrorBar(X,F(X),[DifferenceWithFitted_Upper,DifferenceWithFitted_Lower],{'k-','linewidth',1},0.2);%,'MarkerFaceColor','k','MarkerSize',7);
hold on;
plot(U, 'g-');
hold on;
plot(L, 'b-');

xlabel('Time [day]');
ylabel('Ln (P/P0)');
legend('Experimental','Fitted','Location','NorthEast');

%matlab2tikz('DryWithoutSpacer_AllData_Logistic_SmoothingSpline.tikz', 'height', '\figureheight', 'width', '\figurewidth');