clc, format compact, close all;

% Specify number of stable seconds per interval (e.g. 20 s for 5%, run 1) 
t_value = 1.960;         % 95% BHI t-value for infinitely many measurements (>> 30)
s5_1  = 20;
s5_2  = 20;
s10_1 = 30;
s10_2 = 30;
s20_1 = 40;
s20_2 = 40;
s40_1 = 40;
s40_2 = 40;
s70_1 = 40;
s70_2 = 40;

% Specify error in pressure
dPressure = 0.001;

% Specify filename
filename = 'Commercial_PVDF_K101.txt';

% Call function; output is array of pressures
[pressureArray, dPressureArray, timeArray, rawPressure, time] = PorometryAnalyzer(filename, t_value, s5_1, s5_2, s10_1, s10_2, s20_1, s20_2, s40_1, s40_2, s70_1, s70_2);

setFlowArray = [1:5, 1:5, 1:10, 1:10, 2:2:20, 2:2:20, 5:5:40, 5:5:40, 10:10:70, 10:10:70];
area = 3.142e-04;       % m2
fluxArray = setFlowArray / 100 * 30 / 3600 / area / 1000; % m3/m2 s

rawPressure = rawPressure * 6 / 100;
pressureArray = pressureArray * 6 / 100;


% [~, indexCurve] = min(abs(time-2162.577));    % finding first index to increase pressure
% 
% rawPressure(indexCurve:length(rawPressure)) = rawPressure(indexCurve:length(rawPressure)) / 1.1 * 6;
% pressureArray(16:length(pressureArray)) = pressureArray(16:length(pressureArray)) / 1.1 * 6;

% pressureArray(72:73) = NaN;

% Plot the result
hold on; grid minor;

yyaxis left
plot(time, rawPressure,'k');
plot(timeArray, pressureArray, 'bo');
title('Commercial PVDF-K101'); ylabel('Pressure [bar]'); xlabel('Time [s]');

yyaxis right
plot(timeArray,dPressureArray,'.');
ylabel('95% Confidence Deviation');

hold off;

figure;

hold on

plot(fluxArray([1:5, 11:20, 31:40, 51:58, 67:73]), pressureArray([1:5, 11:20, 31:40, 51:58, 67:73]), 'ko','MarkerFaceColor', 'g','MarkerSize',4.5);
plot(fluxArray([6:10, 21:30, 41:50, 59:66, 74:80]), pressureArray([6:10, 21:30, 41:50, 59:66, 74:80]),'ko','MarkerFaceColor', 'w','MarkerSize',4.5);
legend('First run','Second run','location','northwest')
title('Commercial PVDF-K101'); ylabel('Pressure [bar]'); xlabel('Flux [m3 / m2 s]');
grid minor

for run = [5,10,20,40,70]
    line([fluxArray(run), fluxArray(run)], [0,max(pressureArray)],'LineStyle','--');
end

% pressureArrayTriton = pressureArray;
% timeArrayTriton = timeArray;
% rawPressureTriton = rawPressure;
% timeTriton = time;
