% Author: Jaap Eijsker, s1580167, 28-04-2017
% Supervisor: Hanieh Bazyar, SFI

function [pressureArray, dPressureArray, timeArray, rawPressure, time] = PorometryAnalyzer(filename, t_value, s5_1, s5_2, s10_1, s10_2, s20_1, s20_2, s40_1, s40_2, s70_1, s70_2)

%% Reading a comma-separated text file
clc, format compact;

M = csvread(filename);   % reading data from text file

% Column division: time [s] / setpoint flow [%] / time [s] / measured flow [%] / time [s] / measured pressure [%]
time     =  M(:,1);      % time vector
setflow  =  M(:,2);      % setpoint flow vector
measFlow =  M(:,3);      % measured flow vector
pressure =  M(:,6);      % pressure vector

time(time <= 0) = NaN;
pressure(pressure <= 0) = NaN;
rawPressure = pressure;


% Replace zeros in time array by linear interpolation
time = naninterp(time);
    function X = naninterp(X) 
    % Interpolate over NaNs 
    X(isnan(X)) = interp1(find(~isnan(X)), X(~isnan(X)), find(isnan(X))); 
    end 

hold on
%plot(time,pressure);

%% TODO
% - Implement showing of negative values (the zeroes)
% - Implement error analysis

%% Average of [5 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 0;
timeOffset_2 = 550;
measDuration = 100;

% Run 1
for i = 1:5     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s5_1)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));         % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                      % preallocation for speed

    timeArray5_1(i) = (timeOffset_1 + i*measDuration-0.5*s5_1);             % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure5_1(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    
    pressure5_1(i) = mean(pressureInterval, 'omitnan');                     % calculate average value


end

% Run 2
for i = 1:5     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s5_2)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));         % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                      % preallocation for speed

    timeArray5_2(i) = (timeOffset_2 + i*measDuration-0.5*s5_2);             % creating time vector for x-axis
    
    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure5_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure5_2(i) = mean(pressureInterval, 'omitnan');                     % calculate average value

end


%% Average of [10 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 1650;
timeOffset_2 = 2700;
measDuration = 100;

% Run 1
for i = 1:10     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s10_1)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed

    timeArray10_1(i) = (timeOffset_1 + i*measDuration-0.5*s10_1);            % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure10_1(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure10_1(i) = mean(pressureInterval, 'omitnan');                     % calculate average value

end

% Run 2
for i = 1:10     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s10_2)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed

    timeArray10_2(i) = (timeOffset_2 + i*measDuration-0.5*s10_2);            % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure10_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure10_2(i) = mean(pressureInterval, 'omitnan');                     % calculate average value

end

%% Average of [20 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 4300;
timeOffset_2 = 5350;
measDuration = 100;

% Run 1
for i = 1:10     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s20_1)));   % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));         % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                      % preallocation for speed 
    
    timeArray20_1(i) = (timeOffset_1 + i*measDuration-0.5*s20_1);           % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure20_1(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure20_1(i) = mean(pressureInterval, 'omitnan');                    % calculate average value
    
end

% Run 2
for i = 1:10     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s20_2)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));        % finding last  index of pressure plateau
    pressureInterval = zeros(1,(indexMax - indexMin));                        % preallocation for speed

    timeArray20_2(i) = (timeOffset_2 + i*measDuration-0.5*(s20_2));               % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure20_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure20_2(i) = mean(pressureInterval, 'omitnan');     % calculate average value

end

%% Average of [40 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 6950;
timeOffset_2 = 7800;
measDuration = 100;

% Run 1
for i = 1:8     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s40_1)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed

    timeArray40_1(i) = (timeOffset_1 + i*measDuration-0.5*s40_1);            % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure40_1(i) = dPressure * t_value;                                 % calculate 95% CI (Confidence Interval)
    pressure40_1(i) = mean(pressureInterval, 'omitnan');                    % calculate average value

end

% Run 2
for i = 1:8     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s40_2)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed

    timeArray40_2(i) = (timeOffset_2 + i*measDuration-0.5*s40_2);            % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure40_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure40_2(i) = mean(pressureInterval, 'omitnan');                    % calculate average value

end

%% Average of [70 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 9200;
timeOffset_2 = 9950;
measDuration = 100;

% Run 1
for i = 1:7     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s70_1)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed

    timeArray70_1(i) = (timeOffset_1 + i*measDuration-0.5*s70_1);            % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure70_1(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure70_1(i) = mean(pressureInterval, 'omitnan');                     % calculate average value

end

% Run 2
for i = 1:7     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s70_2)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));          % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                       % preallocation for speed


    timeArray70_2(i) = (timeOffset_2 + i*measDuration-0.5*s70_2);            % creating time vector for x-axis
    
    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure70_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure70_2(i) = mean(pressureInterval, 'omitnan');                     % calculate average value

end

pressureArray  = [pressure5_1, pressure5_2, pressure10_1, pressure10_2,  pressure20_1, pressure20_2, pressure40_1, pressure40_2, pressure70_1, pressure70_2 ];
dPressureArray  = [dPressure5_1, dPressure5_2, dPressure10_1, dPressure10_2,  dPressure20_1, dPressure20_2, dPressure40_1, dPressure40_2, dPressure70_1, dPressure70_2 ];
timeArray      = [timeArray5_1, timeArray5_2, timeArray10_1, timeArray10_2, timeArray20_1, timeArray20_2, timeArray40_1, timeArray40_2, timeArray70_1, timeArray70_2];

end