% Author: Jaap Eijsker, s1580167, 28-04-2017
% Supervisor: Hanieh Bazyar, SFI

function [pressureArray, dPressureArray, timeArray, rawPressure, time] = PorometryAnalyzer(filename, t_value, s70_1)

%% Reading a comma-separated text file
clc, format compact;

M = csvread(filename);   % reading data from text file

% Column division: time [s] / setpoint flow [%] / time [s] / measured flow [%] / time [s] / measured pressure [%]
time     =  M(:,1);      % time vector
setflow  =  M(:,2);      % setpoint flow vector
measFlow =  M(:,3);      % measured flow vector
pressure =  M(:,6);      % pressure vector

time(time <= 0) = NaN;
pressure(pressure <= 0) = NaN;
rawPressure = pressure;


% Replace zeros in time array by linear interpolation
time = naninterp(time);
    function X = naninterp(X) 
    % Interpolate over NaNs 
    X(isnan(X)) = interp1(find(~isnan(X)), X(~isnan(X)), find(isnan(X))); 
    end 

hold on
%plot(time,pressure);

%% TODO
% - Implement showing of negative values (the zeroes)
% - Implement error analysis

%% Average of [70 %]

% Number of stable seconds (standard: 30 s)
timeOffset_1 = 0;
timeOffset_2 = 2550;
measDuration = 100;

% Run 1
for i = 1:35     % for each pressure plateau

    [~, indexMin] = min(abs(time-(timeOffset_1 + i*measDuration-s70_1)));    % finding first index of pressure plateau
    [~, indexMax] = min(abs(time-(timeOffset_1 + i*measDuration)));         % finding last  index of pressure plateau
    pressureInterval = zeros((indexMax - indexMin),1);                      % preallocation for speed

    timeArray70_1(i) = (timeOffset_1 + i*measDuration-0.5*s70_1);             % creating time vector for x-axis

    pressureInterval = pressure(indexMin:indexMax);
    dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
    dPressure70_1(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
    pressure70_1(i) = mean(pressureInterval, 'omitnan');                     % calculate average value


end

% Run 2
% for i = 1:25     % for each pressure plateau
% 
%     [~, indexMin] = min(abs(time-(timeOffset_2 + i*measDuration-s50_2)));    % finding first index of pressure plateau
%     [~, indexMax] = min(abs(time-(timeOffset_2 + i*measDuration)));         % finding last  index of pressure plateau
%     pressureInterval = zeros((indexMax - indexMin),1);                      % preallocation for speed
% 
%     timeArray50_2(i) = (timeOffset_2 + i*measDuration-0.5*s50_2);             % creating time vector for x-axis
%     
%     pressureInterval = pressure(indexMin:indexMax);
%     dPressure = nanstd(pressureInterval)/sqrt(length(pressureInterval));       % calculate mean error
%     dPressure50_2(i) = dPressure * t_value;                                  % calculate 95% CI (Confidence Interval)
%     pressure50_2(i) = mean(pressureInterval, 'omitnan');                     % calculate average value
% 
% end



pressureArray  = [pressure70_1];
dPressureArray  = [dPressure70_1];
timeArray      = [timeArray70_1];

end